#
# spec file for package ghc-accelerate
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name accelerate
Name:           ghc-%{pkg_name}
Version:        0.15.1.0
Release:        9.9
Summary:        An embedded language for accelerated array processing
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
Source1:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/revision/1.cabal#/%{pkg_name}.cabal
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-fclabels-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-hashtables-devel
BuildRequires:  ghc-pretty-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-template-haskell-devel
BuildRequires:  ghc-unordered-containers-devel

%description
'Data.Array.Accelerate' defines an embedded array language for computations for
high-performance computing in Haskell. Computations on multi-dimensional,
regular arrays are expressed in the form of parameterised collective
operations, such as maps, reductions, and permutations. These computations may
then be online compiled and executed on a range of architectures.

[/A simple example/]

As a simple example, consider the computation of a dot product of two vectors
of floating point numbers:

> dotp :: Acc (Vector Float) -> Acc (Vector Float) -> Acc (Scalar Float) > dotp
xs ys = fold (+) 0 (zipWith (*) xs ys)

Except for the type, this code is almost the same as the corresponding Haskell
code on lists of floats. The types indicate that the computation may be
online-compiled for performance - for example, using
'Data.Array.Accelerate.CUDA' it may be on-the-fly off-loaded to the GPU.

[/Available backends/]

Currently, there are two backends:

1. An interpreter that serves as a reference implementation of the intended
semantics of the language, which is included in this package.

2. A CUDA backend generating code for CUDA-capable NVIDIA GPUs:
<http://hackage.haskell.org/package/accelerate-cuda>

Several experimental and/or incomplete backends also exist. If you are
particularly interested in any of these, especially with helping to finish
them, please contact us.

1. Cilk/ICC and OpenCL:
<https://github.com/AccelerateHS/accelerate-backend-kit>

2. Another OpenCL backend: <https://github.com/HIPERFIT/accelerate-opencl>

3. A backend to the Repa array library:
<https://github.com/blambo/accelerate-repa>

4. An infrastructure for generating LLVM code, with backends targeting
multicore CPUs and NVIDIA GPUs:
<https://github.com/AccelerateHS/accelerate-llvm/>

[/Additional components/]

The following support packages are available:

1. 'accelerate-cuda': A high-performance parallel backend targeting
CUDA-enabled NVIDIA GPUs. Requires the NVIDIA CUDA SDK and, for full
functionality, hardware with compute capability 1.1 or greater. See the table
on Wikipedia for supported GPUs:
<http://en.wikipedia.org/wiki/CUDA#Supported_GPUs>

2. 'accelerate-examples': Computational kernels and applications showcasing
/Accelerate/, as well as performance and regression tests.

3. 'accelerate-io': Fast conversion between /Accelerate/ arrays and other
formats, including 'vector' and 'repa'.

4. 'accelerate-fft': Computation of Discrete Fourier Transforms.

Install them from Hackage with 'cabal install PACKAGE'

[/Examples and documentation/]

Haddock documentation is included in the package, and a tutorial is available
on the GitHub wiki: <https://github.com/AccelerateHS/accelerate/wiki>

The 'accelerate-examples' package demonstrates a range of computational kernels
and several complete applications, including:

* An implementation of the Canny edge detection algorithm

* An interactive Mandelbrot set generator

* A particle-based simulation of stable fluid flows

* An /n/-body simulation of gravitational attraction between solid particles

* A cellular automata simulation

* A "password recovery" tool, for dictionary lookup of MD5 hashes

* A simple interactive ray tracer

[/Mailing list and contacts/]

* Mailing list: <accelerate-haskell'googlegroups.com> (discussion of both use
and development welcome).

* Sign up for the mailing list here:
<http://groups.google.com/group/accelerate-haskell>

* Bug reports and issue tracking:
<https://github.com/AccelerateHS/accelerate/issues>

[/Hackage note/]

The module documentation list generated by Hackage is incorrect. The only
exposed modules should be:

* "Data.Array.Accelerate"

* "Data.Array.Accelerate.Interpreter"

* "Data.Array.Accelerate.Data.Complex" .

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}
cp -p %{SOURCE1} %{pkg_name}.cabal

%build
%ghc_lib_build

%install
%ghc_lib_install

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%doc LICENSE

%files devel -f %{name}-devel.files
%doc changelog.md

%changelog
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.15.1.0 revision 1 with cabal2obs.
